@@ -1,5 +1,6 @@
 import datetime
 from files_sdk.api import Api
+from files_sdk.list_obj import ListObj
 from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError
 
 class BundleRecipient:
@@ -28,6 +29,7 @@ class BundleRecipient:
 #   page - int64 - Current page number.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
+#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   bundle_id (required) - int64 - List recipients for the bundle with this ID.
 def list(params = {}, options = {}):
     if "user_id" in params and not isinstance(params["user_id"], int):
@@ -38,12 +40,13 @@ def list(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "action" in params and not isinstance(params["action"], str):
         raise InvalidParameterError("Bad parameter: action must be an str")
+    if "cursor" in params and not isinstance(params["cursor"], str):
+        raise InvalidParameterError("Bad parameter: cursor must be an str")
     if "bundle_id" in params and not isinstance(params["bundle_id"], int):
         raise InvalidParameterError("Bad parameter: bundle_id must be an int")
     if "bundle_id" not in params:
         raise MissingParameterError("Parameter missing: bundle_id")
-    response, options = Api.send_request("GET", "/bundle_recipients", params, options)
-    return [ BundleRecipient(entity_data, options) for entity_data in response.data ]
+    return ListObj(BundleRecipient,"GET", "/bundle_recipients", params, options)
 
 def all(params = {}, options = {}):
     list(params, options)
