@@ -1,5 +1,6 @@
 import datetime
 from files_sdk.api import Api
+from files_sdk.list_obj import ListObj
 from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError
 
 class FileComment:
@@ -71,6 +72,7 @@ class FileComment:
 #   page - int64 - Current page number.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
+#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   path (required) - string - Path to operate on.
 def list_for(path, params = {}, options = {}):
     if not isinstance(params, dict):
@@ -82,12 +84,13 @@ def list_for(path, params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "action" in params and not isinstance(params["action"], str):
         raise InvalidParameterError("Bad parameter: action must be an str")
+    if "cursor" in params and not isinstance(params["cursor"], str):
+        raise InvalidParameterError("Bad parameter: cursor must be an str")
     if "path" in params and not isinstance(params["path"], str):
         raise InvalidParameterError("Bad parameter: path must be an str")
     if "path" not in params:
         raise MissingParameterError("Parameter missing: path")
-    response, options = Api.send_request("GET", "/file_comments/files/{path}".format(path=params['path']), params, options)
-    return [ FileComment(entity_data, options) for entity_data in response.data ]
+    return ListObj(FileComment,"GET", "/file_comments/files/{path}".format(path=params['path']), params, options)
 
 # Parameters:
 #   body (required) - string - Comment body.
