@@ -1,5 +1,6 @@
 import datetime
 from files_sdk.api import Api
+from files_sdk.list_obj import ListObj
 from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError
 
 class SsoStrategy:
@@ -21,6 +22,7 @@ class SsoStrategy:
         'provision_groups': None,     # boolean - Auto-provision group membership based on group memberships on the SSO side?
         'deprovision_users': None,     # boolean - Auto-deprovision users?
         'deprovision_groups': None,     # boolean - Auto-deprovision group membership based on group memberships on the SSO side?
+        'deprovision_behavior': None,     # string - Method used for deprovisioning users.
         'provision_group_default': None,     # string - Comma-separated list of group names for groups to automatically add all auto-provisioned users to.
         'provision_group_exclusion': None,     # string - Comma-separated list of group names for groups (with optional wildcards) that will be excluded from auto-provisioning.
         'provision_group_inclusion': None,     # string - Comma-separated list of group names for groups (with optional wildcards) that will be auto-provisioned.
@@ -58,6 +60,7 @@ class SsoStrategy:
 #   page - int64 - Current page number.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
+#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 def list(params = {}, options = {}):
     if "page" in params and not isinstance(params["page"], int):
         raise InvalidParameterError("Bad parameter: page must be an int")
@@ -65,8 +68,9 @@ def list(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "action" in params and not isinstance(params["action"], str):
         raise InvalidParameterError("Bad parameter: action must be an str")
-    response, options = Api.send_request("GET", "/sso_strategies", params, options)
-    return [ SsoStrategy(entity_data, options) for entity_data in response.data ]
+    if "cursor" in params and not isinstance(params["cursor"], str):
+        raise InvalidParameterError("Bad parameter: cursor must be an str")
+    return ListObj(SsoStrategy,"GET", "/sso_strategies", params, options)
 
 def all(params = {}, options = {}):
     list(params, options)
